==> 0.0.6.tar.gz: lib/pages/online_file_page.dart <==
import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:vone_ipfs/bean/folder_data_entity.dart';
import 'package:vone_ipfs/generated/json/base/json_convert_content.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/utils/toast_utils.dart';
import 'package:vone_ipfs/component/empty_view.dart';

import 'file_preview_page.dart';

class OnlineFilePage extends StatefulWidget {
  ValueChanged<List> resultCallback;
  int maxCount;
  List? filter;

  OnlineFilePage(
    this.resultCallback, {
    Key? key,
    this.maxCount = 9,
    this.filter,
  }) : super(key: key);

  @override
  OnlineFilePageState createState() => new OnlineFilePageState();
}

class OnlineFilePageState extends State<OnlineFilePage> {
  late EasyRefreshController _controller;
  String currentParentID = '119';
  List parentIDs = ['119'];
  List _list = [];
  List selectedFile = [];

  @override
  void initState() {
    super.initState();
    _controller = EasyRefreshController();
    loadFile('119');
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('云端文件'),
        actions: [
          InkWell(
            child: Center(
              child: Padding(
                child: Text('确定'),
                padding: EdgeInsets.symmetric(horizontal: 15),
              ),
            ),
            onTap: () {
              widget.resultCallback(selectedFile);
              Navigator.pop(context);
            },
          )
        ],
        centerTitle: true,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildTips(),
          _buildFileList(),
        ],
      ),
    );
  }

  _buildTips() {
    return Padding(
      padding: EdgeInsets.all(10),
      child: Wrap(
        spacing: 10,
        children: [
          Visibility(
            child: InkWell(
              child: Text(
                '返回到上一级',
                style: TextStyle(fontSize: 14, color: Colors.blue),
              ),
              onTap: () {
                parentIDs.removeLast();
                currentParentID = parentIDs.last;
                loadFile(currentParentID);
              },
            ),
            visible: parentIDs.length > 1,
          ),
          Text(
            '只能上传jpg/png文件',
            style: TextStyle(fontSize: 14, color: Colors.black87),
          )
        ],
      ),
    );
  }

  _buildFileList() {
    return Expanded(
      child: EasyRefresh(
          controller: _controller,
          header: ClassicalHeader(
              enableInfiniteRefresh: false,
              refreshText: '下拉刷新',
              refreshReadyText: '释放刷新',
              refreshingText: '正在刷新...',
              refreshedText: '刷新完成',
              refreshFailedText: '刷新失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          footer: ClassicalFooter(
              enableInfiniteLoad: true,
              loadText: '拉动加载',
              loadReadyText: '释放加载',
              loadingText: '正在加载...',
              loadedText: '加载完成',
              loadFailedText: '加载失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          onRefresh: () async {
            loadFile(currentParentID);
            _controller.finishRefresh();
            _controller.resetLoadState();
          },
          onLoad: () async {
            _controller.finishLoad(noMore: true);
          },
          emptyWidget: _list.length>0?null:EmptyView(),
          child:ListView.builder(
            itemBuilder: (context, index) {
              return _buildFileItem(index);
            },
            itemCount: _list.length,
          )),
    );
  }

  Widget _buildFileItem(int index) {
    return InkWell(
      child: Container(
        padding: const EdgeInsets.all(10),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            IPFSUtils.getFileIconBySuffix("${_list[index].fileMeta.fileName}",fileType: "${_list[index].fileMeta.fileType}"),
            const SizedBox(
              width: 15,
            ),
            Expanded(
                child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  '${_list[index].fileMeta.fileName}',
                  style: const TextStyle(fontSize: 16, color: Colors.black87),
                ),
                // const SizedBox(
                //   height: 8,
                // ),
                // const Text.rich(TextSpan(children: [
                //   TextSpan(
                //     text: '2022-01-12',
                //     style: TextStyle(fontSize: 12, color: Colors.grey),
                //   ),
                //   TextSpan(
                //     text: '    10M',
                //     style: TextStyle(fontSize: 12, color: Colors.grey),
                //   )
                // ])),
              ],
            )),
            // Icon(Icons.panorama_fish_eye,size: 20,color: Color(0xFF999999),)
            Visibility(
                visible: !IPFSUtils.isDir('${_list[index].fileMeta.fileType}'),
                child: InkWell(
                  child: Padding(
                    child: Icon(
                      isSelected(_list[index].fileID)
                          ? Icons.check_circle
                          : Icons.radio_button_unchecked,
                      size: 20,
                      color: isSelected(_list[index].fileID)
                          ? Colors.blue
                          : Color(0xFF999999),
                    ),
                    padding: EdgeInsets.symmetric(horizontal: 10),
                  ),
                  onTap: () {
                    setState(() {
                      if (isSelected(_list[index].fileID)) {
                        selectedFile.removeWhere(
                            (element) => element.fileID == _list[index].fileID);
                      } else {
                        if(selectedFile.length>=widget.maxCount){
                          ToastUtils.show('最多可选择${widget.maxCount}个文件');
                          return;
                        }
                        selectedFile.add(_list[index]);
                      }
                    });
                  },
                ))
          ],
        ),
      ),
      onTap: () {
        if (IPFSUtils.isDir('${_list[index].fileMeta.fileType}')) {
          //如果是文件夹,进入下一级
          currentParentID = '${_list[index].fileID}';
          parentIDs.add(currentParentID);
          loadFile('${_list[index].fileID}');
        } else {
          Navigator.push(context, MaterialPageRoute(builder: (context) {
            return FilePreviewPage(
                fileUrl: IPFSUtils.instance!.getFilePath(
                    _list[index].fileID, _list[index].fileMeta.fileName));
          }));
        }
      },
    );
  }

  isSelected(fileId) {
    return selectedFile.where((element) => element.fileID == fileId).length > 0;
  }

  loadFile(String parentID) async {
    Response response;
    Dio dio = Dio();
    Map<String, dynamic> param = {
      "UserID": IPFSUtils.instance!.userId,
      "SecretKey": IPFSUtils.instance!.secretKey,
      "ParentID": parentID
    };
    response =
        await dio.get<String>(HttpApi.getFolderList, queryParameters: param);
    if (200 == response.statusCode) {
      FolderDataEntity fileData = JsonConvert.fromJsonAsT<FolderDataEntity>(
          jsonDecode(response.data.toString()));
      if (fileData.code == 0) {
        setState(() {
          _list = fileData.data?.fileList ?? [];
        });
      } else {
        setState(() {
          _list = [];
        });
      }
    } else {
      setState(() {
        _list = [];
      });
    }
  }

  @override
  void dispose() {
    super.dispose();
  }
}

==> 0.0.8.tar.gz: lib/pages/online_file_page.dart <==
import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:vone_ipfs/bean/folder_data_entity.dart';
import 'package:vone_ipfs/generated/json/base/json_convert_content.dart';
import 'package:vone_ipfs/net/http_api.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/utils/toast_utils.dart';
import 'package:vone_ipfs/component/empty_view.dart';

import 'file_preview_page.dart';

class OnlineFilePage extends StatefulWidget {
  ValueChanged<List> resultCallback;
  int maxCount;
  List? filter;
  String dirId;
  String dirName;

  OnlineFilePage(
    this.dirId,
    this.dirName,
    this.resultCallback, {
    Key? key,
    this.maxCount = 9,
    this.filter,
  }) : super(key: key);

  @override
  OnlineFilePageState createState() => new OnlineFilePageState();
}

class OnlineFilePageState extends State<OnlineFilePage> {
  late EasyRefreshController _controller;
  String currentParentID = '';
  List parentIDs = [];
  List _list = [];
  List selectedFile = [];

  @override
  void initState() {
    super.initState();
    _controller = EasyRefreshController();
    currentParentID = widget.dirId;
    parentIDs.add(widget.dirId);
    loadFile(currentParentID);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('云端文件'),
        actions: [
          InkWell(
            child: Center(
              child: Padding(
                child: Text('确定'),
                padding: EdgeInsets.symmetric(horizontal: 15),
              ),
            ),
            onTap: () {
              widget.resultCallback(selectedFile);
              Navigator.pop(context);
            },
          )
        ],
        centerTitle: true,
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildTips(),
          _buildFileList(),
        ],
      ),
    );
  }

  _buildTips() {
    return Padding(
      padding: EdgeInsets.all(10),
      child: Wrap(
        spacing: 10,
        children: [
          Visibility(
            child: InkWell(
              child: Text(
                '返回到上一级',
                style: TextStyle(fontSize: 14, color: Colors.blue),
              ),
              onTap: () {
                parentIDs.removeLast();
                currentParentID = parentIDs.last;
                loadFile(currentParentID);
              },
            ),
            visible: parentIDs.length > 1,
          ),
          Text(
            '只能上传jpg/png文件',
            style: TextStyle(fontSize: 14, color: Colors.black87),
          )
        ],
      ),
    );
  }

  _buildFileList() {
    return Expanded(
      child: EasyRefresh(
          controller: _controller,
          header: ClassicalHeader(
              enableInfiniteRefresh: false,
              refreshText: '下拉刷新',
              refreshReadyText: '释放刷新',
              refreshingText: '正在刷新...',
              refreshedText: '刷新完成',
              refreshFailedText: '刷新失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          footer: ClassicalFooter(
              enableInfiniteLoad: true,
              loadText: '拉动加载',
              loadReadyText: '释放加载',
              loadingText: '正在加载...',
              loadedText: '加载完成',
              loadFailedText: '加载失败',
              noMoreText: '没有更多数据',
              infoText: '更新于 %T',
              infoColor: const Color(0xFF999999)),
          onRefresh: () async {
            loadFile(currentParentID);
            _controller.finishRefresh();
            _controller.resetLoadState();
          },
          onLoad: () async {
            _controller.finishLoad(noMore: true);
          },
          emptyWidget: _list.length > 0 ? null : EmptyView(),
          child: ListView.builder(
            itemBuilder: (context, index) {
              return _buildFileItem(index);
            },
            itemCount: _list.length,
          )),
    );
  }

  Widget _buildFileItem(int index) {
    return InkWell(
      child: Container(
        padding: const EdgeInsets.all(10),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            IPFSUtils.getFileIconBySuffix("${_list[index].fileMeta.fileName}",
                fileType: "${_list[index].fileMeta.fileType}"),
            const SizedBox(
              width: 15,
            ),
            Expanded(
                child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  '${_list[index].fileMeta.fileName}',
                  style: const TextStyle(fontSize: 16, color: Colors.black87),
                ),
                // const SizedBox(
                //   height: 8,
                // ),
                // const Text.rich(TextSpan(children: [
                //   TextSpan(
                //     text: '2022-01-12',
                //     style: TextStyle(fontSize: 12, color: Colors.grey),
                //   ),
                //   TextSpan(
                //     text: '    10M',
                //     style: TextStyle(fontSize: 12, color: Colors.grey),
                //   )
                // ])),
              ],
            )),
            // Icon(Icons.panorama_fish_eye,size: 20,color: Color(0xFF999999),)
            Visibility(
                visible: !IPFSUtils.isDir('${_list[index].fileMeta.fileType}'),
                child: InkWell(
                  child: Padding(
                    child: Icon(
                      isSelected(_list[index].fileID)
                          ? Icons.check_circle
                          : Icons.radio_button_unchecked,
                      size: 20,
                      color: isSelected(_list[index].fileID)
                          ? Colors.blue
                          : Color(0xFF999999),
                    ),
                    padding: EdgeInsets.symmetric(horizontal: 10),
                  ),
                  onTap: () {
                    setState(() {
                      if (isSelected(_list[index].fileID)) {
                        selectedFile.removeWhere(
                            (element) => element.fileID == _list[index].fileID);
                      } else {
                        if (selectedFile.length >= widget.maxCount) {
                          ToastUtils.show('最多可选择${widget.maxCount}个文件');
                          return;
                        }
                        selectedFile.add(_list[index]);
                      }
                    });
                  },
                ))
          ],
        ),
      ),
      onTap: () {
        if (IPFSUtils.isDir('${_list[index].fileMeta.fileType}')) {
          //如果是文件夹,进入下一级
          currentParentID = '${_list[index].fileID}';
          parentIDs.add(currentParentID);
          loadFile('${_list[index].fileID}');
        } else {
          Navigator.push(context, MaterialPageRoute(builder: (context) {
            return FilePreviewPage(
                fileUrl: IPFSUtils.instance!.getFilePath(
                    _list[index].fileID, _list[index].fileMeta.fileName));
          }));
        }
      },
    );
  }

  isSelected(fileId) {
    return selectedFile.where((element) => element.fileID == fileId).length > 0;
  }

  loadFile(String parentID) async {
    Response response;
    Dio dio = Dio();
    Map<String, dynamic> param = {
      "UserID": IPFSUtils.instance!.userId,
      "SecretKey": IPFSUtils.instance!.secretKey,
      "ParentID": parentID
    };
    response =
        await dio.get<String>(HttpApi.getFolderList, queryParameters: param);
    if (200 == response.statusCode) {
      FolderDataEntity fileData = JsonConvert.fromJsonAsT<FolderDataEntity>(
          jsonDecode(response.data.toString()));
      if (fileData.code == 0) {
        setState(() {
          _list = fileData.data?.fileList ?? [];
        });
      } else {
        setState(() {
          _list = [];
        });
      }
    } else {
      setState(() {
        _list = [];
      });
    }
  }

  @override
  void dispose() {
    super.dispose();
  }
}
